@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ফ’ৰ্ট নেলছন)',
         'America/Fortaleza' => 'ব্ৰাজিলিয়াৰ সময় (ফোৰ্টালেজা)',
         'America/Glace_Bay' => 'আটলাণ্টিক সময় (গ্লেচ উপসাগৰ)',
-        'America/Godthab' => 'পশ্চিম গ্ৰীণলেণ্ডৰ সময় (নুক)',
+        'America/Godthab' => 'গ্ৰীণলেণ্ড সময় (নুক)',
         'America/Goose_Bay' => 'আটলাণ্টিক সময় (গুছ উপসাগৰ)',
         'America/Grand_Turk' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (গ্ৰেণ্ড টাৰ্ক)',
         'America/Grenada' => 'আটলাণ্টিক সময় (গ্ৰেনাডা)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'আটলাণ্টিক সময় (মণ্টছেৰাট)',
         'America/Nassau' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নাছাউ)',
         'America/New_York' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নিউ ইয়ৰ্ক)',
-        'America/Nipigon' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (নিপিগন)',
         'America/Nome' => 'আলাস্কাৰ সময় (নোম)',
         'America/Noronha' => 'ফাৰ্নাণ্ডো ডে নোৰোন্‌হাৰ সময়',
         'America/North_Dakota/Beulah' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (বেউলাহ, উত্তৰ ডাকোটা)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (নিউ ছালেম, উত্তৰ ডাকোটা)',
         'America/Ojinaga' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (অ’জিনাগা)',
         'America/Panama' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পানামা)',
-        'America/Pangnirtung' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (পাংনিৰ্টুংগ)',
         'America/Paramaribo' => 'ছুৰিনামৰ সময় (পাৰামাৰিবো)',
         'America/Phoenix' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (ফিনিক্স)',
         'America/Port-au-Prince' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (প’ৰ্ট-ঔ-প্ৰিন্স)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'আমাজনৰ সময় (পোৰ্টো ভেল্‌হো)',
         'America/Puerto_Rico' => 'আটলাণ্টিক সময় (পুৱেৰ্টো ৰিকো)',
         'America/Punta_Arenas' => 'চিলিৰ সময় (পুণ্টা এৰিনাছ)',
-        'America/Rainy_River' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰেইনী নদী)',
         'America/Rankin_Inlet' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰেংকিন ইনলেট)',
         'America/Recife' => 'ব্ৰাজিলিয়াৰ সময় (ৰেচাইফ)',
         'America/Regina' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰেজিনা)',
         'America/Resolute' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৰিজ’লিউট)',
         'America/Rio_Branco' => 'ব্ৰাজিল সময় (ৰিঅ’ ব্ৰাংকো)',
-        'America/Santa_Isabel' => 'উত্তৰ-পশ্চিম মেক্সিকোৰ সময় (Santa Isabel)',
         'America/Santarem' => 'ব্ৰাজিলিয়াৰ সময় (ছেণ্টাৰেম)',
         'America/Santiago' => 'চিলিৰ সময় (ছেণ্টিয়াগো)',
         'America/Santo_Domingo' => 'আটলাণ্টিক সময় (ছাণ্টো ডোমিংগো)',
         'America/Sao_Paulo' => 'ব্ৰাজিলিয়াৰ সময় (ছাও পাউলো)',
-        'America/Scoresbysund' => 'পূব গ্ৰীণলেণ্ডৰ সময় (ইটোকোৰ্টোৰমিট)',
+        'America/Scoresbysund' => 'গ্ৰীণলেণ্ড সময় (ইটোকোৰ্টোৰমিট)',
         'America/Sitka' => 'আলাস্কাৰ সময় (ছিট্‌‌কা)',
         'America/St_Barthelemy' => 'আটলাণ্টিক সময় (ছেইণ্ট বাৰ্থলেমে)',
         'America/St_Johns' => 'নিউফাউণ্ডলেণ্ডৰ সময় (ছেইণ্ট জনচ্)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ছুইফ্ট কাৰেণ্ট)',
         'America/Tegucigalpa' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (টেগুচিগাল্পা)',
         'America/Thule' => 'আটলাণ্টিক সময় (থ্যুলে)',
-        'America/Thunder_Bay' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (থাণ্ডাৰ উপসাগৰ)',
         'America/Tijuana' => 'উত্তৰ আমেৰিকাৰ প্ৰশান্ত সময় (তিজুৱানা)',
         'America/Toronto' => 'উত্তৰ আমেৰিকাৰ প্ৰাচ্য সময় (ট’ৰ’ণ্টো)',
         'America/Tortola' => 'আটলাণ্টিক সময় (টোৰ্টোলা)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'য়ুকোন সময় (হোৱাইটহৰ্চ)',
         'America/Winnipeg' => 'উত্তৰ আমেৰিকাৰ কেন্দ্ৰীয় সময় (ৱিনিপেগ)',
         'America/Yakutat' => 'আলাস্কাৰ সময় (য়াকুটাট)',
-        'America/Yellowknife' => 'উত্তৰ আমেৰিকাৰ পৰ্ব্বতীয় সময় (য়েল্লোনাইফ)',
-        'Antarctica/Casey' => 'এণ্টাৰ্কটিকা সময় (কেছী)',
+        'Antarctica/Casey' => 'পাশ্চাত্য অষ্ট্ৰেলিয়াৰ সময় (কেছী)',
         'Antarctica/Davis' => 'ডেভিছৰ সময়',
         'Antarctica/DumontDUrville' => 'ডুমোণ্ট-ডি আৰ্ভিলৰ সময়',
         'Antarctica/Macquarie' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (মেক্‌কুৱেৰী)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'ভোষ্টকৰ সময়',
         'Arctic/Longyearbyen' => 'মধ্য ইউৰোপীয় সময় (লংগেইৰবায়েন)',
         'Asia/Aden' => 'আৰবীয় সময় (আদেন)',
-        'Asia/Almaty' => 'পূব কাজাখস্তানৰ সময় (আলমাটি)',
+        'Asia/Almaty' => 'পশ্চিম কাজাখস্তানৰ সময় (আলমাটি)',
         'Asia/Amman' => 'প্ৰাচ্য ইউৰোপীয় সময় (আম্মান)',
         'Asia/Anadyr' => 'ৰাছিয়া সময় (আনাডিৰ)',
         'Asia/Aqtau' => 'পশ্চিম কাজাখস্তানৰ সময় (এক্যোট্যাও)',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'পাশ্চাত্য ইণ্ডোনেচিয়াৰ সময় (পোণ্টিয়াংক)',
         'Asia/Pyongyang' => 'কোৰিয়াৰ সময় (প্যংয়াং)',
         'Asia/Qatar' => 'আৰবীয় সময় (কাটাৰ)',
-        'Asia/Qostanay' => 'পূব কাজাখস্তানৰ সময় (ক’ষ্টেনী)',
+        'Asia/Qostanay' => 'পশ্চিম কাজাখস্তানৰ সময় (ক’ষ্টেনী)',
         'Asia/Qyzylorda' => 'পশ্চিম কাজাখস্তানৰ সময় (কেজিলোৰ্ডা)',
         'Asia/Rangoon' => 'ম্যানমাৰৰ সময় (য়াঙোন)',
         'Asia/Riyadh' => 'আৰবীয় সময় (ৰিয়াধ)',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'মধ্য অষ্ট্ৰেলিয়াৰ সময় (এডিলেইড)',
         'Australia/Brisbane' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (ব্ৰিচবেন)',
         'Australia/Broken_Hill' => 'মধ্য অষ্ট্ৰেলিয়াৰ সময় (ব্ৰোকেন হিল)',
-        'Australia/Currie' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (ক্যুৰি)',
         'Australia/Darwin' => 'মধ্য অষ্ট্ৰেলিয়াৰ সময় (ডাৰউইন)',
         'Australia/Eucla' => 'অষ্ট্ৰেলিয়াৰ কেন্দ্ৰীয় পাশ্চাত্য সময় (ইউক্লা)',
         'Australia/Hobart' => 'প্ৰাচ্য অষ্ট্ৰেলিয়াৰ সময় (হোবাৰ্ট)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'প্ৰাচ্য ইউৰোপীয় সময় (তেলিন)',
         'Europe/Tirane' => 'মধ্য ইউৰোপীয় সময় (টাইৰেন)',
         'Europe/Ulyanovsk' => 'মস্কোৰ সময় (উল্যানোভ্‌স্ক)',
-        'Europe/Uzhgorod' => 'প্ৰাচ্য ইউৰোপীয় সময় (উজ্গোৰোড)',
         'Europe/Vaduz' => 'মধ্য ইউৰোপীয় সময় (ভাদুজ)',
         'Europe/Vatican' => 'মধ্য ইউৰোপীয় সময় (ভেটিকান)',
         'Europe/Vienna' => 'মধ্য ইউৰোপীয় সময় (ভিয়েনা)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'ভোল্গোগ্ৰাডৰ সময়',
         'Europe/Warsaw' => 'মধ্য ইউৰোপীয় সময় (ৱাৰছাও)',
         'Europe/Zagreb' => 'মধ্য ইউৰোপীয় সময় (জাগ্ৰেব)',
-        'Europe/Zaporozhye' => 'প্ৰাচ্য ইউৰোপীয় সময় (জাপোৰোজাই)',
         'Europe/Zurich' => 'মধ্য ইউৰোপীয় সময় (জুৰিখ)',
         'Indian/Antananarivo' => 'পূব আফ্ৰিকাৰ সময় (এণ্টানানাৰিভো)',
         'Indian/Chagos' => 'ভাৰত মহাসাগৰীয় সময় (চাগোছ)',
@@ -412,7 +403,6 @@ return [
         'Pacific/Guadalcanal' => 'চোলোমোন দ্বীপপুঞ্জৰ সময় (গুৱাডলকানাল)',
         'Pacific/Guam' => 'চামোৰোৰ মান সময় (গুৱাম)',
         'Pacific/Honolulu' => 'হাৱাই-এলিউশ্বনৰ সময় (Honolulu)',
-        'Pacific/Johnston' => 'হাৱাই-এলিউশ্বনৰ সময় (জনষ্টন)',
         'Pacific/Kiritimati' => 'লাইন দ্বীপপুঞ্জৰ সময় (কিৰিটিমাটি)',
         'Pacific/Kosrae' => 'কোছৰায়ে সময়',
         'Pacific/Kwajalein' => 'মাৰ্শ্বাল দ্বীপপুঞ্জৰ সময় (কোৱাজালিন)',
@@ -437,6 +427,5 @@ return [
         'Pacific/Wake' => 'ৱেক দ্বীপৰ সময়',
         'Pacific/Wallis' => 'ৱালিছ আৰু ফুটুনাৰ সময়',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
