@@ -93,7 +93,7 @@ return [
         'America/Costa_Rica' => 'eur ar Cʼhreiz (Costa Rica)',
         'America/Creston' => 'eur ar Menezioù (Creston)',
         'America/Cuiaba' => 'eur an Amazon (Cuiaba)',
-        'America/Curacao' => 'eur an Atlantel (Curacao)',
+        'America/Curacao' => 'eur an Atlantel (Curaçao)',
         'America/Danmarkshavn' => 'Amzer keitat Greenwich (AKG) (Danmarkshavn)',
         'America/Dawson' => 'eur Kanada (Dawson)',
         'America/Dawson_Creek' => 'eur ar Menezioù (Dawson Creek)',
@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'eur ar Menezioù (Fort Nelson)',
         'America/Fortaleza' => 'eur Brasília (Fortaleza)',
         'America/Glace_Bay' => 'eur an Atlantel (Glace Bay)',
-        'America/Godthab' => 'eur Greunland ar Cʼhornôg (Nuuk (Godthåb))',
+        'America/Godthab' => 'eur Greunland (Nuuk (Godthåb))',
         'America/Goose_Bay' => 'eur an Atlantel (Goose Bay)',
         'America/Grand_Turk' => 'eur ar Reter (Grand Turk)',
         'America/Grenada' => 'eur an Atlantel (Grenada)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'eur an Atlantel (Montserrat)',
         'America/Nassau' => 'eur ar Reter (Nassau)',
         'America/New_York' => 'eur ar Reter (New York)',
-        'America/Nipigon' => 'eur ar Reter (Nipigon)',
         'America/Nome' => 'eur Alaska (Nome)',
         'America/Noronha' => 'eur Fernando de Noronha',
         'America/North_Dakota/Beulah' => 'eur ar Cʼhreiz (Beulah, North Dakota)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'eur ar Cʼhreiz (New Salem, North Dakota)',
         'America/Ojinaga' => 'eur ar Cʼhreiz (Ojinaga)',
         'America/Panama' => 'eur ar Reter (Panamá)',
-        'America/Pangnirtung' => 'eur ar Reter (Pangnirtung)',
         'America/Paramaribo' => 'eur Surinam (Paramaribo)',
         'America/Phoenix' => 'eur ar Menezioù (Phoenix)',
         'America/Port-au-Prince' => 'eur ar Reter (Port-au-Prince)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'eur an Amazon (Porto Velho)',
         'America/Puerto_Rico' => 'eur an Atlantel (Puerto Rico)',
         'America/Punta_Arenas' => 'eur Chile (Punta Arenas)',
-        'America/Rainy_River' => 'eur ar Cʼhreiz (Rainy River)',
         'America/Rankin_Inlet' => 'eur ar Cʼhreiz (Rankin Inlet)',
         'America/Recife' => 'eur Brasília (Recife)',
         'America/Regina' => 'eur ar Cʼhreiz (Regina)',
         'America/Resolute' => 'eur ar Cʼhreiz (Resolute)',
         'America/Rio_Branco' => 'eur Brazil (Rio Branco)',
-        'America/Santa_Isabel' => 'eur Gwalarn Mecʼhiko (Santa Isabel)',
         'America/Santarem' => 'eur Brasília (Santarem)',
         'America/Santiago' => 'eur Chile (Santiago)',
         'America/Santo_Domingo' => 'eur an Atlantel (Santo Domingo)',
         'America/Sao_Paulo' => 'eur Brasília (São Paulo)',
-        'America/Scoresbysund' => 'eur Greunland ar Reter (Ittoqqortoormiit)',
+        'America/Scoresbysund' => 'eur Greunland (Ittoqqortoormiit)',
         'America/Sitka' => 'eur Alaska (Sitka)',
         'America/St_Barthelemy' => 'eur an Atlantel (Saint Barthélemy)',
         'America/St_Johns' => 'eur Newfoundland (Saint Johnʼs)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'eur ar Cʼhreiz (Swift Current)',
         'America/Tegucigalpa' => 'eur ar Cʼhreiz (Tegucigalpa)',
         'America/Thule' => 'eur an Atlantel (Qânâq)',
-        'America/Thunder_Bay' => 'eur ar Reter (Thunder Bay)',
         'America/Tijuana' => 'eur an Habask (Tijuana)',
         'America/Toronto' => 'eur ar Reter (Toronto)',
         'America/Tortola' => 'eur an Atlantel (Tortola)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'eur Kanada (Whitehorse)',
         'America/Winnipeg' => 'eur ar Cʼhreiz (Winnipeg)',
         'America/Yakutat' => 'eur Alaska (Yakutat)',
-        'America/Yellowknife' => 'eur ar Menezioù (Yellowknife)',
-        'Antarctica/Casey' => 'eur Antarktika (Casey)',
+        'Antarctica/Casey' => 'eur Aostralia ar Cʼhornôg (Casey)',
         'Antarctica/Davis' => 'eur Davis',
         'Antarctica/DumontDUrville' => 'eur Dumont-d’Urville',
         'Antarctica/Macquarie' => 'eur Aostralia ar Reter (Macquarie)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'eur Vostok',
         'Arctic/Longyearbyen' => 'eur Kreizeuropa (Longyearbyen)',
         'Asia/Aden' => 'eur Arabia (Aden)',
-        'Asia/Almaty' => 'eur Kazakstan ar Reter (Almaty)',
+        'Asia/Almaty' => 'eur Kazakstan ar Cʼhornôg (Almaty)',
         'Asia/Amman' => 'eur Europa ar Reter (Amman)',
         'Asia/Anadyr' => 'eur Anadyrʼ',
         'Asia/Aqtau' => 'eur Kazakstan ar Cʼhornôg (Aqtau)',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'eur Indonezia ar Cʼhornôg (Pontianak)',
         'Asia/Pyongyang' => 'eur Korea (Pʼyongyang)',
         'Asia/Qatar' => 'eur Arabia (Qatar)',
-        'Asia/Qostanay' => 'eur Kazakstan ar Reter (Qostanay)',
+        'Asia/Qostanay' => 'eur Kazakstan ar Cʼhornôg (Qostanay)',
         'Asia/Qyzylorda' => 'eur Kazakstan ar Cʼhornôg (Qyzylorda)',
         'Asia/Rangoon' => 'eur Myanmar (Yangon)',
         'Asia/Riyadh' => 'eur Arabia (Riyadh)',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'eur Kreizaostralia (Adelaide)',
         'Australia/Brisbane' => 'eur Aostralia ar Reter (Brisbane)',
         'Australia/Broken_Hill' => 'eur Kreizaostralia (Broken Hill)',
-        'Australia/Currie' => 'eur Aostralia ar Reter (Currie)',
         'Australia/Darwin' => 'eur Kreizaostralia (Darwin)',
         'Australia/Eucla' => 'eur Kreizaostralia ar Cʼhornôg (Eucla)',
         'Australia/Hobart' => 'eur Aostralia ar Reter (Hobart)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'eur Europa ar Reter (Tallinn)',
         'Europe/Tirane' => 'eur Kreizeuropa (Tiranë)',
         'Europe/Ulyanovsk' => 'eur Moskov (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'eur Europa ar Reter (Uzhgorod)',
         'Europe/Vaduz' => 'eur Kreizeuropa (Vaduz)',
         'Europe/Vatican' => 'eur Kreizeuropa (Vatikan)',
         'Europe/Vienna' => 'eur Kreizeuropa (Vienna)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'eur Volgograd',
         'Europe/Warsaw' => 'eur Kreizeuropa (Varsovia)',
         'Europe/Zagreb' => 'eur Kreizeuropa (Zagreb)',
-        'Europe/Zaporozhye' => 'eur Europa ar Reter (Zaporozhye)',
         'Europe/Zurich' => 'eur Kreizeuropa (Zurich)',
         'Indian/Antananarivo' => 'eur Afrika ar Reter (Antananarivo)',
         'Indian/Chagos' => 'eur Meurvor Indez (Chagos)',
@@ -412,7 +403,6 @@ return [
         'Pacific/Guadalcanal' => 'eur Inizi Salomon (Guadalcanal)',
         'Pacific/Guam' => 'eur Chamorro (Guam)',
         'Pacific/Honolulu' => 'eur Hawaii hag an Aleouted (Honolulu)',
-        'Pacific/Johnston' => 'eur Hawaii hag an Aleouted (Johnston)',
         'Pacific/Kiritimati' => 'eur Line Islands (Kiritimati)',
         'Pacific/Kosrae' => 'eur Kosrae',
         'Pacific/Kwajalein' => 'eur Inizi Marshall (Kwajalein)',
@@ -437,6 +427,5 @@ return [
         'Pacific/Wake' => 'eur Wake Island',
         'Pacific/Wallis' => 'eur Wallis ha Futuna',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
