@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'Mountain-tijd (Fort Nelson)',
         'America/Fortaleza' => 'Braziliaanse tijd (Fortaleza)',
         'America/Glace_Bay' => 'Atlantic-tijd (Glace Bay)',
-        'America/Godthab' => 'West-Groenlandse tijd (Nuuk)',
+        'America/Godthab' => 'tijd in Groenland (Nuuk)',
         'America/Goose_Bay' => 'Atlantic-tijd (Goose Bay)',
         'America/Grand_Turk' => 'Eastern-tijd (Grand Turk)',
         'America/Grenada' => 'Atlantic-tijd (Grenada)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'Atlantic-tijd (Montserrat)',
         'America/Nassau' => 'Eastern-tijd (Nassau)',
         'America/New_York' => 'Eastern-tijd (New York)',
-        'America/Nipigon' => 'Eastern-tijd (Nipigon)',
         'America/Nome' => 'Alaska-tijd (Nome)',
         'America/Noronha' => 'Fernando de Noronha-tijd',
         'America/North_Dakota/Beulah' => 'Central-tijd (Beulah, Noord-Dakota)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'Central-tijd (New Salem, Noord-Dakota)',
         'America/Ojinaga' => 'Central-tijd (Ojinaga)',
         'America/Panama' => 'Eastern-tijd (Panama)',
-        'America/Pangnirtung' => 'Eastern-tijd (Pangnirtung)',
         'America/Paramaribo' => 'Surinaamse tijd (Paramaribo)',
         'America/Phoenix' => 'Mountain-tijd (Phoenix)',
         'America/Port-au-Prince' => 'Eastern-tijd (Port-au-Prince)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'Amazone-tijd (Porto Velho)',
         'America/Puerto_Rico' => 'Atlantic-tijd (Puerto Rico)',
         'America/Punta_Arenas' => 'Chileense tijd (Punta Arenas)',
-        'America/Rainy_River' => 'Central-tijd (Rainy River)',
         'America/Rankin_Inlet' => 'Central-tijd (Rankin Inlet)',
         'America/Recife' => 'Braziliaanse tijd (Recife)',
         'America/Regina' => 'Central-tijd (Regina)',
         'America/Resolute' => 'Central-tijd (Resolute)',
         'America/Rio_Branco' => 'Acre-tijd (Rio Branco)',
-        'America/Santa_Isabel' => 'Noordwest-Mexicaanse tijd (Santa Isabel)',
         'America/Santarem' => 'Braziliaanse tijd (Santarem)',
         'America/Santiago' => 'Chileense tijd (Santiago)',
         'America/Santo_Domingo' => 'Atlantic-tijd (Santo Domingo)',
         'America/Sao_Paulo' => 'Braziliaanse tijd (São Paulo)',
-        'America/Scoresbysund' => 'Oost-Groenlandse tijd (Ittoqqortoormiit)',
+        'America/Scoresbysund' => 'tijd in Groenland (Ittoqqortoormiit)',
         'America/Sitka' => 'Alaska-tijd (Sitka)',
         'America/St_Barthelemy' => 'Atlantic-tijd (Saint-Barthélemy)',
         'America/St_Johns' => 'Newfoundland-tijd (Saint John’s)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'Central-tijd (Swift Current)',
         'America/Tegucigalpa' => 'Central-tijd (Tegucigalpa)',
         'America/Thule' => 'Atlantic-tijd (Thule)',
-        'America/Thunder_Bay' => 'Eastern-tijd (Thunder Bay)',
         'America/Tijuana' => 'Pacific-tijd (Tijuana)',
         'America/Toronto' => 'Eastern-tijd (Toronto)',
         'America/Tortola' => 'Atlantic-tijd (Tortola)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'Yukon-tijd (Whitehorse)',
         'America/Winnipeg' => 'Central-tijd (Winnipeg)',
         'America/Yakutat' => 'Alaska-tijd (Yakutat)',
-        'America/Yellowknife' => 'Mountain-tijd (Yellowknife)',
-        'Antarctica/Casey' => 'Casey tijd',
+        'Antarctica/Casey' => 'West-Australische tijd (Casey)',
         'Antarctica/Davis' => 'Davis-tijd',
         'Antarctica/DumontDUrville' => 'Dumont-d’Urville-tijd',
         'Antarctica/Macquarie' => 'Oost-Australische tijd (Macquarie)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'Vostok-tijd',
         'Arctic/Longyearbyen' => 'Midden-Europese tijd (Longyearbyen)',
         'Asia/Aden' => 'Arabische tijd (Aden)',
-        'Asia/Almaty' => 'Oost-Kazachse tijd (Alma-Ata)',
+        'Asia/Almaty' => 'West-Kazachse tijd (Alma-Ata)',
         'Asia/Amman' => 'Oost-Europese tijd (Amman)',
         'Asia/Anadyr' => 'Anadyr-tijd',
         'Asia/Aqtau' => 'West-Kazachse tijd (Aqtau)',
@@ -227,7 +221,7 @@ return [
         'Asia/Bahrain' => 'Arabische tijd (Bahrein)',
         'Asia/Baku' => 'Azerbeidzjaanse tijd (Bakoe)',
         'Asia/Bangkok' => 'Indochinese tijd (Bangkok)',
-        'Asia/Barnaul' => 'Rusland-tijd (Barnaul)',
+        'Asia/Barnaul' => 'tijd in Rusland (Barnaul)',
         'Asia/Beirut' => 'Oost-Europese tijd (Beiroet)',
         'Asia/Bishkek' => 'Kirgizische tijd (Bisjkek)',
         'Asia/Brunei' => 'Bruneise tijd',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'West-Indonesische tijd (Pontianak)',
         'Asia/Pyongyang' => 'Koreaanse tijd (Pyongyang)',
         'Asia/Qatar' => 'Arabische tijd (Qatar)',
-        'Asia/Qostanay' => 'Oost-Kazachse tijd (Qostanay)',
+        'Asia/Qostanay' => 'West-Kazachse tijd (Qostanay)',
         'Asia/Qyzylorda' => 'West-Kazachse tijd (Qyzylorda)',
         'Asia/Rangoon' => 'Myanmarese tijd (Rangoon)',
         'Asia/Riyadh' => 'Arabische tijd (Riyad)',
@@ -289,9 +283,9 @@ return [
         'Asia/Tehran' => 'Iraanse tijd (Teheran)',
         'Asia/Thimphu' => 'Bhutaanse tijd (Thimphu)',
         'Asia/Tokyo' => 'Japanse tijd (Tokio)',
-        'Asia/Tomsk' => 'Rusland-tijd (Tomsk)',
+        'Asia/Tomsk' => 'tijd in Rusland (Tomsk)',
         'Asia/Ulaanbaatar' => 'Ulaanbaatar-tijd',
-        'Asia/Urumqi' => 'China-tijd (Urumqi)',
+        'Asia/Urumqi' => 'tijd in China (Urumqi)',
         'Asia/Ust-Nera' => 'Vladivostok-tijd (Ust-Nera)',
         'Asia/Vientiane' => 'Indochinese tijd (Vientiane)',
         'Asia/Vladivostok' => 'Vladivostok-tijd',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'Midden-Australische tijd (Adelaide)',
         'Australia/Brisbane' => 'Oost-Australische tijd (Brisbane)',
         'Australia/Broken_Hill' => 'Midden-Australische tijd (Broken Hill)',
-        'Australia/Currie' => 'Oost-Australische tijd (Currie)',
         'Australia/Darwin' => 'Midden-Australische tijd (Darwin)',
         'Australia/Eucla' => 'Midden-Australische westelijke tijd (Eucla)',
         'Australia/Hobart' => 'Oost-Australische tijd (Hobart)',
@@ -342,11 +335,11 @@ return [
         'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
         'Europe/Helsinki' => 'Oost-Europese tijd (Helsinki)',
         'Europe/Isle_of_Man' => 'Greenwich Mean Time (Isle of Man)',
-        'Europe/Istanbul' => 'Turkije-tijd (Istanboel)',
+        'Europe/Istanbul' => 'tijd in Turkije (Istanboel)',
         'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
         'Europe/Kaliningrad' => 'Oost-Europese tijd (Kaliningrad)',
         'Europe/Kiev' => 'Oost-Europese tijd (Kiev)',
-        'Europe/Kirov' => 'Rusland-tijd (Kirov)',
+        'Europe/Kirov' => 'tijd in Rusland (Kirov)',
         'Europe/Lisbon' => 'West-Europese tijd (Lissabon)',
         'Europe/Ljubljana' => 'Midden-Europese tijd (Ljubljana)',
         'Europe/London' => 'Greenwich Mean Time (Londen)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'Oost-Europese tijd (Tallinn)',
         'Europe/Tirane' => 'Midden-Europese tijd (Tirana)',
         'Europe/Ulyanovsk' => 'Moskou-tijd (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'Oost-Europese tijd (Oezjhorod)',
         'Europe/Vaduz' => 'Midden-Europese tijd (Vaduz)',
         'Europe/Vatican' => 'Midden-Europese tijd (Vaticaanstad)',
         'Europe/Vienna' => 'Midden-Europese tijd (Wenen)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'Wolgograd-tijd',
         'Europe/Warsaw' => 'Midden-Europese tijd (Warschau)',
         'Europe/Zagreb' => 'Midden-Europese tijd (Zagreb)',
-        'Europe/Zaporozhye' => 'Oost-Europese tijd (Zaporizja)',
         'Europe/Zurich' => 'Midden-Europese tijd (Zürich)',
         'Indian/Antananarivo' => 'Oost-Afrikaanse tijd (Antananarivo)',
         'Indian/Chagos' => 'Indische Oceaan-tijd (Chagosarchipel)',
@@ -412,7 +403,6 @@ return [
         'Pacific/Guadalcanal' => 'Salomonseilandse tijd (Guadalcanal)',
         'Pacific/Guam' => 'Chamorro-tijd (Guam)',
         'Pacific/Honolulu' => 'Hawaii-Aleoetische tijd (Honolulu)',
-        'Pacific/Johnston' => 'Hawaii-Aleoetische tijd (Johnston)',
         'Pacific/Kiritimati' => 'Line-eilandse tijd (Kiritimati)',
         'Pacific/Kosrae' => 'Kosraese tijd',
         'Pacific/Kwajalein' => 'Marshalleilandse tijd (Kwajalein)',
@@ -437,6 +427,5 @@ return [
         'Pacific/Wake' => 'Wake-eilandse tijd',
         'Pacific/Wallis' => 'Wallis en Futunase tijd',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
