@@ -54,7 +54,7 @@ return [
         'Africa/Tripoli' => 'houa fakaʻeulope-hahake (Tripoli)',
         'Africa/Tunis' => 'houa fakaʻeulope-loto (Tunis)',
         'Africa/Windhoek' => 'houa fakaʻafelika-loto (Windhoek)',
-        'America/Adak' => 'houa fakahauaʻi (Adak)',
+        'America/Adak' => 'houa fakahauaiʻi-aleuti (Adak)',
         'America/Anchorage' => 'houa fakaʻalasika (Anchorage)',
         'America/Anguilla' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Anguilla)',
         'America/Antigua' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Antigua)',
@@ -106,7 +106,7 @@ return [
         'America/Fort_Nelson' => 'houa fakaʻamelika-tokelau moʻunga (Fort Nelson)',
         'America/Fortaleza' => 'houa fakapalāsila (Fortaleza)',
         'America/Glace_Bay' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Glace Bay)',
-        'America/Godthab' => 'houa fakafonuamata-hihifo (Nuuk)',
+        'America/Godthab' => 'Taimi Kulinilani (Nuuk)',
         'America/Goose_Bay' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Goose Bay)',
         'America/Grand_Turk' => 'houa fakaʻamelika-tokelau hahake (Grand Turk)',
         'America/Grenada' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Grenada)',
@@ -156,7 +156,6 @@ return [
         'America/Montserrat' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Montserrat)',
         'America/Nassau' => 'houa fakaʻamelika-tokelau hahake (Nassau)',
         'America/New_York' => 'houa fakaʻamelika-tokelau hahake (Niu ʻIoke)',
-        'America/Nipigon' => 'houa fakaʻamelika-tokelau hahake (Nipigon)',
         'America/Nome' => 'houa fakaʻalasika (Nome)',
         'America/Noronha' => 'houa fakafēnanito-te-nolōnia (Noronha)',
         'America/North_Dakota/Beulah' => 'houa fakaʻamelika-tokelau loto (Beulah, North Dakota)',
@@ -164,7 +163,6 @@ return [
         'America/North_Dakota/New_Salem' => 'houa fakaʻamelika-tokelau loto (New Salem, North Dakota)',
         'America/Ojinaga' => 'houa fakaʻamelika-tokelau loto (Ojinaga)',
         'America/Panama' => 'houa fakaʻamelika-tokelau hahake (Panama)',
-        'America/Pangnirtung' => 'houa fakaʻamelika-tokelau hahake (Pangnirtung)',
         'America/Paramaribo' => 'houa fakasuliname (Paramaribo)',
         'America/Phoenix' => 'houa fakaʻamelika-tokelau moʻunga (Phoenix)',
         'America/Port-au-Prince' => 'houa fakaʻamelika-tokelau hahake (Port-au-Prince)',
@@ -172,18 +170,16 @@ return [
         'America/Porto_Velho' => 'houa fakaʻamasōne (Porto Velho)',
         'America/Puerto_Rico' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Puerto Rico)',
         'America/Punta_Arenas' => 'houa fakasili (Punta Arenas)',
-        'America/Rainy_River' => 'houa fakaʻamelika-tokelau loto (Rainy River)',
         'America/Rankin_Inlet' => 'houa fakaʻamelika-tokelau loto (Rankin Inlet)',
         'America/Recife' => 'houa fakapalāsila (Recife)',
         'America/Regina' => 'houa fakaʻamelika-tokelau loto (Regina)',
         'America/Resolute' => 'houa fakaʻamelika-tokelau loto (Resolute)',
         'America/Rio_Branco' => 'houa fakaʻakelī (Rio Branco)',
-        'America/Santa_Isabel' => 'houa fakamekisikou-tokelauhihifo (Santa Isabel)',
         'America/Santarem' => 'houa fakapalāsila (Santarem)',
         'America/Santiago' => 'houa fakasili (Santiago)',
         'America/Santo_Domingo' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Santo Domingo)',
         'America/Sao_Paulo' => 'houa fakapalāsila (Sao Paulo)',
-        'America/Scoresbysund' => 'houa fakafonuamata-hahake (Ittoqqortoormiit)',
+        'America/Scoresbysund' => 'Taimi Kulinilani (Ittoqqortoormiit)',
         'America/Sitka' => 'houa fakaʻalasika (Sitka)',
         'America/St_Barthelemy' => 'houa fakaʻamelika-tokelau ʻatalanitiki (St. Barthélemy)',
         'America/St_Johns' => 'houa fakafonuaʻilofoʻou (St. John’s)',
@@ -194,7 +190,6 @@ return [
         'America/Swift_Current' => 'houa fakaʻamelika-tokelau loto (Swift Current)',
         'America/Tegucigalpa' => 'houa fakaʻamelika-tokelau loto (Tegucigalpa)',
         'America/Thule' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Thule)',
-        'America/Thunder_Bay' => 'houa fakaʻamelika-tokelau hahake (Thunder Bay)',
         'America/Tijuana' => 'houa fakaʻamelika-tokelau pasifika (Tijuana)',
         'America/Toronto' => 'houa fakaʻamelika-tokelau hahake (Toronto)',
         'America/Tortola' => 'houa fakaʻamelika-tokelau ʻatalanitiki (Tortola)',
@@ -202,8 +197,7 @@ return [
         'America/Whitehorse' => 'houa fakaiukoni (Whitehorse)',
         'America/Winnipeg' => 'houa fakaʻamelika-tokelau loto (Winnipeg)',
         'America/Yakutat' => 'houa fakaʻalasika (Yakutat)',
-        'America/Yellowknife' => 'houa fakaʻamelika-tokelau moʻunga (Yellowknife)',
-        'Antarctica/Casey' => 'houa fakakeesi (Casey)',
+        'Antarctica/Casey' => 'houa fakaʻaositelēlia-hihifo (Casey)',
         'Antarctica/Davis' => 'houa fakatavisi (Davis)',
         'Antarctica/DumontDUrville' => 'houa fakatūmoni-tūvile (Dumont d’Urville)',
         'Antarctica/Macquarie' => 'houa fakaʻaositelēlia-hahake (Macquarie)',
@@ -216,7 +210,7 @@ return [
         'Antarctica/Vostok' => 'houa fakavositoki (Vostok)',
         'Arctic/Longyearbyen' => 'houa fakaʻeulope-loto (Longyearbyen)',
         'Asia/Aden' => 'houa fakaʻalepea (Aden)',
-        'Asia/Almaty' => 'houa fakakasakitani-hahake (Almaty)',
+        'Asia/Almaty' => 'houa fakakasakitani-hihifo (Almaty)',
         'Asia/Amman' => 'houa fakaʻeulope-hahake (Amman)',
         'Asia/Anadyr' => 'houa fakalūsia-ʻanatili (Anadyr)',
         'Asia/Aqtau' => 'houa fakakasakitani-hihifo (Aqtau)',
@@ -242,7 +236,7 @@ return [
         'Asia/Dushanbe' => 'houa fakatasikitani (Dushanbe)',
         'Asia/Famagusta' => 'houa fakaʻeulope-hahake (Famagusta)',
         'Asia/Gaza' => 'houa fakaʻeulope-hahake (Gaza)',
-        'Asia/Hebron' => 'houa fakaʻeulope-hahake (Hebron)',
+        'Asia/Hebron' => 'houa fakaʻeulope-hahake (Hepeloni)',
         'Asia/Hong_Kong' => 'houa fakahongi-kongi (Hong Kong)',
         'Asia/Hovd' => 'houa fakahovite (Hovd)',
         'Asia/Irkutsk' => 'houa fakalūsia-ʻīkutisiki (Irkutsk)',
@@ -272,7 +266,7 @@ return [
         'Asia/Pontianak' => 'houa fakaʻinitonisia-hihifo (Pontianak)',
         'Asia/Pyongyang' => 'houa fakakōlea (Pyongyang)',
         'Asia/Qatar' => 'houa fakaʻalepea (Qatar)',
-        'Asia/Qostanay' => 'houa fakakasakitani-hahake (Qostanay)',
+        'Asia/Qostanay' => 'houa fakakasakitani-hihifo (Qostanay)',
         'Asia/Qyzylorda' => 'houa fakakasakitani-hihifo (Qyzylorda)',
         'Asia/Rangoon' => 'houa fakapema (Rangoon)',
         'Asia/Riyadh' => 'houa fakaʻalepea (Riyadh)',
@@ -311,7 +305,6 @@ return [
         'Australia/Adelaide' => 'houa fakaʻaositelēlia-loto (Atelaite)',
         'Australia/Brisbane' => 'houa fakaʻaositelēlia-hahake (Pelisipane)',
         'Australia/Broken_Hill' => 'houa fakaʻaositelēlia-loto (Broken Hill)',
-        'Australia/Currie' => 'houa fakaʻaositelēlia-hahake (Currie)',
         'Australia/Darwin' => 'houa fakaʻaositelēlia-loto (Darwin)',
         'Australia/Eucla' => 'houa fakaʻaositelēlia-loto-hihifo (Eucla)',
         'Australia/Hobart' => 'houa fakaʻaositelēlia-hahake (Hobart)',
@@ -374,7 +367,6 @@ return [
         'Europe/Tallinn' => 'houa fakaʻeulope-hahake (Tallinn)',
         'Europe/Tirane' => 'houa fakaʻeulope-loto (Tirane)',
         'Europe/Ulyanovsk' => 'houa fakalūsia-mosikou (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'houa fakaʻeulope-hahake (Uzhhorod)',
         'Europe/Vaduz' => 'houa fakaʻeulope-loto (Vaduz)',
         'Europe/Vatican' => 'houa fakaʻeulope-loto (Vatikani)',
         'Europe/Vienna' => 'houa fakaʻeulope-loto (Vienna)',
@@ -382,7 +374,6 @@ return [
         'Europe/Volgograd' => 'houa fakalūsia-volikokalati (Volgograd)',
         'Europe/Warsaw' => 'houa fakaʻeulope-loto (Warsaw)',
         'Europe/Zagreb' => 'houa fakaʻeulope-loto (Zagreb)',
-        'Europe/Zaporozhye' => 'houa fakaʻeulope-hahake (Zaporozhye)',
         'Europe/Zurich' => 'houa fakaʻeulope-loto (Zurich)',
         'Indian/Antananarivo' => 'houa fakaʻafelika-hahake (Antananarivo)',
         'Indian/Chagos' => 'houa fakamoanaʻinitia (Chagos)',
@@ -411,8 +402,7 @@ return [
         'Pacific/Gambier' => 'houa fakakamipiē',
         'Pacific/Guadalcanal' => 'houa fakaʻotumotusolomone (Kuatākanali)',
         'Pacific/Guam' => 'houa fakakamolo (Kuami)',
-        'Pacific/Honolulu' => 'houa fakahauaʻi (Honolulu)',
-        'Pacific/Johnston' => 'houa fakahauaʻi (Sionesitoni)',
+        'Pacific/Honolulu' => 'houa fakahauaiʻi-aleuti (Honolulu)',
         'Pacific/Kiritimati' => 'houa fakaʻotumotulaine (Kilisimasi)',
         'Pacific/Kosrae' => 'houa fakakosilae',
         'Pacific/Kwajalein' => 'houa fakaʻotumotumasolo (Kuasaleni)',
@@ -437,6 +427,5 @@ return [
         'Pacific/Wake' => 'houa fakamotuueke',
         'Pacific/Wallis' => 'houa fakaʻuvea mo futuna',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
