@@ -111,6 +111,9 @@ class ExecutableFinderTest extends TestCase
         }
     }
 
+    /**
+     * @runInSeparateProcess
+     */
     public function testFindBatchExecutableOnWindows()
     {
         if (\ini_get('open_basedir')) {
@@ -120,24 +123,58 @@ class ExecutableFinderTest extends TestCase
             $this->markTestSkipped('Can be only tested on windows');
         }
 
-        $target = tempnam(sys_get_temp_dir(), 'example-windows-executable');
+        $target = str_replace('.tmp', '_tmp', tempnam(sys_get_temp_dir(), 'example-windows-executable'));
 
-        touch($target);
-        touch($target.'.BAT');
+        try {
+            touch($target);
+            touch($target.'.BAT');
 
-        $this->assertFalse(is_executable($target));
+            $this->assertFalse(is_executable($target));
 
-        putenv('PATH='.sys_get_temp_dir());
+            putenv('PATH='.sys_get_temp_dir());
 
-        $finder = new ExecutableFinder();
-        $result = $finder->find(basename($target), false);
-
-        unlink($target);
-        unlink($target.'.BAT');
+            $finder = new ExecutableFinder();
+            $result = $finder->find(basename($target), false);
+        } finally {
+            unlink($target);
+            unlink($target.'.BAT');
+        }
 
         $this->assertSamePath($target.'.BAT', $result);
     }
 
+    /**
+     * @runInSeparateProcess
+     */
+    public function testEmptyDirInPath()
+    {
+        putenv(sprintf('PATH=%s%s', \dirname(\PHP_BINARY), \PATH_SEPARATOR));
+
+        try {
+            touch('executable');
+            chmod('executable', 0700);
+
+            $finder = new ExecutableFinder();
+            $result = $finder->find('executable');
+
+            $this->assertSame(sprintf('.%sexecutable', \DIRECTORY_SEPARATOR), $result);
+        } finally {
+            unlink('executable');
+        }
+    }
+
+    public function testFindBuiltInCommandOnWindows()
+    {
+        if ('\\' !== \DIRECTORY_SEPARATOR) {
+            $this->markTestSkipped('Can be only tested on windows');
+        }
+
+        $finder = new ExecutableFinder();
+        $this->assertSame('rmdir', strtolower($finder->find('RMDIR')));
+        $this->assertSame('cd', strtolower($finder->find('cd')));
+        $this->assertSame('move', strtolower($finder->find('MoVe')));
+    }
+
     private function assertSamePath($expected, $tested)
     {
         if ('\\' === \DIRECTORY_SEPARATOR) {
