@@ -12,7 +12,6 @@
 namespace Symfony\Component\RateLimiter;
 
 use Symfony\Component\Lock\LockFactory;
-use Symfony\Component\Lock\NoLock;
 use Symfony\Component\OptionsResolver\Options;
 use Symfony\Component\OptionsResolver\OptionsResolver;
 use Symfony\Component\RateLimiter\Policy\FixedWindowLimiter;
@@ -27,11 +26,11 @@ use Symfony\Component\RateLimiter\Storage\StorageInterface;
  */
 final class RateLimiterFactory
 {
-    private $config;
-    private $storage;
-    private $lockFactory;
+    private array $config;
+    private StorageInterface $storage;
+    private ?LockFactory $lockFactory;
 
-    public function __construct(array $config, StorageInterface $storage, LockFactory $lockFactory = null)
+    public function __construct(array $config, StorageInterface $storage, ?LockFactory $lockFactory = null)
     {
         $this->storage = $storage;
         $this->lockFactory = $lockFactory;
@@ -42,34 +41,29 @@ final class RateLimiterFactory
         $this->config = $options->resolve($config);
     }
 
-    public function create(string $key = null): LimiterInterface
+    public function create(?string $key = null): LimiterInterface
     {
         $id = $this->config['id'].'-'.$key;
-        $lock = $this->lockFactory ? $this->lockFactory->createLock($id) : new NoLock();
+        $lock = $this->lockFactory?->createLock($id);
 
-        switch ($this->config['policy']) {
-            case 'token_bucket':
-                return new TokenBucketLimiter($id, $this->config['limit'], $this->config['rate'], $this->storage, $lock);
-
-            case 'fixed_window':
-                return new FixedWindowLimiter($id, $this->config['limit'], $this->config['interval'], $this->storage, $lock);
-
-            case 'sliding_window':
-                return new SlidingWindowLimiter($id, $this->config['limit'], $this->config['interval'], $this->storage, $lock);
-
-            case 'no_limit':
-                return new NoLimiter();
-
-            default:
-                throw new \LogicException(sprintf('Limiter policy "%s" does not exists, it must be either "token_bucket", "sliding_window", "fixed_window" or "no_limit".', $this->config['policy']));
-        }
+        return match ($this->config['policy']) {
+            'token_bucket' => new TokenBucketLimiter($id, $this->config['limit'], $this->config['rate'], $this->storage, $lock),
+            'fixed_window' => new FixedWindowLimiter($id, $this->config['limit'], $this->config['interval'], $this->storage, $lock),
+            'sliding_window' => new SlidingWindowLimiter($id, $this->config['limit'], $this->config['interval'], $this->storage, $lock),
+            'no_limit' => new NoLimiter(),
+            default => throw new \LogicException(sprintf('Limiter policy "%s" does not exists, it must be either "token_bucket", "sliding_window", "fixed_window" or "no_limit".', $this->config['policy'])),
+        };
     }
 
     protected static function configureOptions(OptionsResolver $options): void
     {
         $intervalNormalizer = static function (Options $options, string $interval): \DateInterval {
             try {
-                return (new \DateTimeImmutable())->diff(new \DateTimeImmutable('+'.$interval));
+                // Create DateTimeImmutable from unix timesatmp, so the default timezone is ignored and we don't need to
+                // deal with quirks happening when modifying dates using a timezone with DST.
+                $now = \DateTimeImmutable::createFromFormat('U', time());
+
+                return $now->diff($now->modify('+'.$interval));
             } catch (\Exception $e) {
                 if (!preg_match('/Failed to parse time string \(\+([^)]+)\)/', $e->getMessage(), $m)) {
                     throw $e;
